## Description
[Provide a detailed description of the changes in this PR]

## Related Issues
[Link to related issues using #issue-number format]

## Documentation PR
[Link to related associated PR in the repo]

## Type of Change
- Bug fix
- New feature
- Breaking change
- Documentation update
- Other (please describe):

[Choose one of the above types of changes]

## Testing
[How have you tested the change?]

## Checklist
- [ ] I have added tests that prove my fix is effective or my feature works
- [ ] I have updated the documentation accordingly
- [ ] I have added an appropriate example to the documentation to outline the feature
- [ ] My changes generate no new warnings
- [ ] Any dependent changes have been merged and published

By submitting this pull request, I confirm that you can use, modify, copy, and redistribute this contribution, under the terms of your choice.
